## **v0.6.1 (2026-03-24)
#### 新设备
- 优化rsc类型设备的数据包处理间隔


## **v0.6.0 (2026-01-16)
#### 新设备
- C256RS设备支持设备连接、信号采集、阻抗测量、文件记录、刺激等功能
- ARS信号采集、阻抗测量、文件记录等功能
- 修复其他问题


## **v0.5.1.1** (2025-08-24)
#### 🐛 Bug Fixed
- 修复仅选择一个通道时，自动保存功能异常的问题


## **v0.5.1** (2025-08-04)

#### ⚙️ Changed
- C16R通道映射调整为按老的脑电帽位点映射（固件端做了映射）

- 开放底层参数，支持EDF/BDF文件中存储大量事件(>1个/秒)

- 优化实时信号数据订阅（发布/订阅模式），在调用者使用不规范时，多个订阅者之间不会互相干扰


## **v0.5.0** (2025-07-29)

#### 🚀 Added

- *新增C16R搜索与连接*  
   支持C16R类型设备的搜索与连接

- *C16R信号采集/停止控制*  
   支持信号采集的参数配置
   支持信号采集的启动与停止控制

- *C16R数据自动记录*  
   采集到的信号数据自动保存为bdf文件

- *C16R采集通道设置*  
   - 支持数字模式通道配置
   - 支持名称模式通道配置  
   - 支持两种模式混合使用

#### ⚙️ Changed

- *性能提升*
   - 信号接收效率优化  
   - 指令拆包方式优化

- *日志系统改进* 
   - 日志级别精细化调整，减少不必要的日志信息
   - 日志文案清晰化